==> openshift-model-machine-5.10.1-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MachineSetStatusBuilder extends io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluentImpl<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusBuilder>{
  public MachineSetStatusBuilder() {
    this(false);
  }
  public MachineSetStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new MachineSetStatus(), validationEnabled);
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MachineSetStatus(), validationEnabled);
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus instance) {
    this(fluent, instance, false);
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluent<?> fluent,io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorReason(instance.getErrorReason()); 
    fluent.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus instance) {
    this(instance,false);
  }
  public MachineSetStatusBuilder(io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorReason(instance.getErrorReason()); 
    this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.machine.v1beta1.MachineSetStatus build() {
    MachineSetStatus buildable = new MachineSetStatus(fluent.getAvailableReplicas(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.getFullyLabeledReplicas(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MachineSetStatusBuilder that = (MachineSetStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-machine-6.2.0-sources.jar: io/fabric8/openshift/api/model/machine/v1beta1/MachineSetStatusBuilder.java <==
package io.fabric8.openshift.api.model.machine.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MachineSetStatusBuilder extends MachineSetStatusFluentImpl<MachineSetStatusBuilder> implements VisitableBuilder<MachineSetStatus,MachineSetStatusBuilder>{
  public MachineSetStatusBuilder() {
    this(false);
  }
  public MachineSetStatusBuilder(Boolean validationEnabled) {
    this(new MachineSetStatus(), validationEnabled);
  }
  public MachineSetStatusBuilder(MachineSetStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public MachineSetStatusBuilder(MachineSetStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MachineSetStatus(), validationEnabled);
  }
  public MachineSetStatusBuilder(MachineSetStatusFluent<?> fluent,MachineSetStatus instance) {
    this(fluent, instance, false);
  }
  public MachineSetStatusBuilder(MachineSetStatusFluent<?> fluent,MachineSetStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailableReplicas(instance.getAvailableReplicas()); 
    fluent.withErrorMessage(instance.getErrorMessage()); 
    fluent.withErrorReason(instance.getErrorReason()); 
    fluent.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    fluent.withObservedGeneration(instance.getObservedGeneration()); 
    fluent.withReadyReplicas(instance.getReadyReplicas()); 
    fluent.withReplicas(instance.getReplicas()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MachineSetStatusBuilder(MachineSetStatus instance) {
    this(instance,false);
  }
  public MachineSetStatusBuilder(MachineSetStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailableReplicas(instance.getAvailableReplicas()); 
    this.withErrorMessage(instance.getErrorMessage()); 
    this.withErrorReason(instance.getErrorReason()); 
    this.withFullyLabeledReplicas(instance.getFullyLabeledReplicas()); 
    this.withObservedGeneration(instance.getObservedGeneration()); 
    this.withReadyReplicas(instance.getReadyReplicas()); 
    this.withReplicas(instance.getReplicas()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MachineSetStatusFluent<?> fluent;
  Boolean validationEnabled;
  public MachineSetStatus build() {
    MachineSetStatus buildable = new MachineSetStatus(fluent.getAvailableReplicas(),fluent.getErrorMessage(),fluent.getErrorReason(),fluent.getFullyLabeledReplicas(),fluent.getObservedGeneration(),fluent.getReadyReplicas(),fluent.getReplicas());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
